@@ -42,9 +42,10 @@
 ##' @param lrm set to TRUE to include logistic regression estimates w rcspline
 ##' @param orm set to TRUE to include ordinal logistic regression estimates w rcspline (mean + quantiles in `tau`)
 ##' @param hare set to TRUE to include hazard regression estimtes of incidence at `times`, using the `polspline` package
+##' @param ordsurv set to TRUE to include ordinal regression estimates of incidence at `times`, using the `rms` package `adapt_orm` and `survest.orm` functions
 ##' @param lrm_args a `list` of optional arguments to pass to `lrm` when `lrm=TRUE`, e.g., `list(maxit=20)`
 ##' @param family link function for ordinal regression (see `rms::orm`)
-##' @param k number of knots to use for ols and/or qreg rcspline
+##' @param k number of knots to use for ols, lrm,  qreg restricted cubic splines.  Linearity is forced for binary `y` when the minimum of the number of events and number of non-events is below 10 for a by-group.  For `ordsurv=TRUE` is the maximum number of knots tried and is passed as argument `maxk` to the `rms` `adapt_orm` function.
 ##' @param tau quantile numbers to estimate with quantile regression
 ##' @param melt set to TRUE to melt data table and derive Type and Statistic
 ##' @param data 
@@ -63,7 +64,7 @@ movStats <- function(formula, stat=NULL, discrete=FALSE,
                      trans=function(x) x, itrans=function(x) x,
                      loess=FALSE,
                      ols=FALSE, qreg=FALSE, lrm=FALSE,
-                     orm=FALSE, hare=FALSE, 
+                     orm=FALSE, hare=FALSE, ordsurv=FALSE,
                      lrm_args=NULL, family='logistic',
                      k=5, tau=(1:3)/4, melt=FALSE,
                      data=environment(formula),
@@ -105,6 +106,9 @@ movStats <- function(formula, stat=NULL, discrete=FALSE,
   if(sec) {
     if(hare) if(! requireNamespace('polspline', quietly=TRUE))
                stop('polspline package must be installed if hare=TRUE')
+    if(ordsurv) if(! requireNamespace('rms', quietly=TRUE))
+               stop('rms package must be installed if ordsurv=TRUE')
+
     Y2 <- Y[, 2]
     Y  <- Y[, 1]
     } else Y2 <- rep(1, nrow(mf))
@@ -299,9 +303,10 @@ movStats <- function(formula, stat=NULL, discrete=FALSE,
     }
 
     if(lrm) {
-      f <- if(length(lrm_args))
-        do.call(rms::lrm, c(list(y ~ rms::rcs(x, .knots.), data=s), lrm_args)) else
-        rms::lrm(y ~ rms::rcs(x, .knots.), data=s)
+      f <- if(min(s[, sum(y == 1)], s[, sum(y == 0)]) < 10) f <- rms::lrm(y ~ x, data=s)
+      else if(length(lrm_args))
+        do.call(rms::lrm, c(list(y ~ rms::rcs(x, .knots.), data=s), lrm_args))
+        else rms::lrm(y ~ rms::rcs(x, .knots.), data=s)
       pc <- predict(f, dat, type='fitted')
       w[, 'LR Proportion' := pc]
     }
@@ -342,6 +347,16 @@ movStats <- function(formula, stat=NULL, discrete=FALSE,
       }
     }
 
+    if(ordsurv) {
+      aorm <- getFromNamespace('adapt_orm', 'rms')
+      f <- aorm(x, rms::Ocens(y, ifelse(y2 == 1, y, Inf)), maxk=k)
+      for(ti in times) {
+        inc     <- 1 - rms::survest(f, dat, times=ti, conf.int=0)$surv
+        newname <- paste0('orm ', ti, '-', tunits)
+        w[, (newname) := inc]
+      }
+    }
+
     w[, by := by]
     R <- rbind(R, w)
   }
